OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakti",
    "Loading" : "Loading",
    "Name" : "Ime",
    "Title" : "Naslov",
    "Download" : "Preuzmi",
    "Delete" : "Obriši",
    "Groups" : "Grupe",
    "New contact" : "Novi kontakt",
    "Rename" : "Preimenuj",
    "Enabled" : "Aktivirano",
    "Disabled" : "Onemogućeno",
    "can edit" : "mogu mijenjati",
    "First name" : "Ime",
    "Last name" : "Prezime",
    "Not grouped" : "Nije grupirano",
    "Nickname" : "Nadimak",
    "Additional names" : "Dodatna imena",
    "Notes" : "Notes",
    "Website" : "Web-prezentacija",
    "Location" : "Lokacija",
    "Home" : "Kuća",
    "Work" : "Posao",
    "Other" : "Ostali",
    "Address" : "Adresa",
    "City" : "Grad",
    "State or province" : "Savezna država ili pokrajina",
    "Postal code" : "Poštanski broj",
    "Country" : "Država",
    "Birthday" : "Rođendan",
    "Email" : "E-pošta",
    "Instant messaging" : "Razmjena izravnih poruka",
    "Phone" : "Telefon",
    "Mobile" : "Mobitel",
    "Fax" : "Faks",
    "Pager" : "Dojavljivač",
    "Voice" : "Glas",
    "None" : "Ništa",
    "Unknown" : "Nepoznato"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
